Stan Math Library: stan::math::value_type< T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::value_type< T > Struct Template Reference

Primary template class for metaprogram to compute the type of values stored in a container. More...

`#include <value_type.hpp>`

## Detailed Description

### template<typename T>
struct stan::math::value_type< T >

Primary template class for metaprogram to compute the type of values stored in a container.

Only the specializations have behavior that can be used, and all implement a typedef `type` for the type of the values in the container.

tparam T type of container.

Definition at line 18 of file value_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/value_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.